Enum rustc_driver::CompilationUnstable
[-] [+]
[src]
pub enum Compilation {
Stop,
Continue,
}Variants
Stop | |
Continue |
pub enum Compilation {
Stop,
Continue,
}Stop | |
Continue |
impl Compilationfn and_then<F: FnOnce() -> Compilation>(self, next: F) -> Compilationimpl PartialEq for Compilationfn eq(&self, __arg_0: &Compilation) -> boolfn ne(&self, __arg_0: &Compilation) -> boolimpl Eq for Compilationimpl Debug for Compilationimpl Clone for Compilationfn clone(&self) -> Compilationfn clone_from(&mut self, source: &Self)impl Copy for Compilation
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).