Function rustc_driver::versionUnstable
[-] [+]
[src]
pub fn version(binary: &str, matches: &Matches)
Prints version information and returns None on success or an error message on panic.
pub fn version(binary: &str, matches: &Matches)
Prints version information and returns None on success or an error message on panic.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).